TarFileSingleDataset
====================

.. currentmodule:: pykeen.datasets.base

.. autoclass:: TarFileSingleDataset
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TarFileSingleDataset.ratios

   .. rubric:: Attributes Documentation

   .. autoattribute:: ratios
